@@ -300,18 +300,22 @@ class bigjob(api.base.bigjob):
         # in Condor case bootstrap script is staged 
         # (Python app cannot be passed inline in Condor job description)
         if lrms_saga_url.scheme.startswith("condor")==True:
-            logger.debug("Using Condor")
+
             condor_bootstrap_filename = os.path.join("/tmp", "bootstrap-"+str(self.uuid))
             condor_bootstrap_file = open(condor_bootstrap_filename, "w")
             condor_bootstrap_file.write(bootstrap_script)
             condor_bootstrap_file.close()
+            logger.debug("Using Condor - bootstrap file: " + condor_bootstrap_filename)
            
             jd.executable = "/usr/bin/env"
             jd.arguments = ["python",  os.path.basename(condor_bootstrap_filename)]                
             bj_file_transfers = []
             file_transfer_spec = condor_bootstrap_filename + " > " + os.path.basename(condor_bootstrap_filename)
             bj_file_transfers.append(file_transfer_spec)
-            output_file_transfer_spec = os.path.join(self.working_directory, "output.tar.gz") +" < output.tar.gz"
+            output_file_name = "output-" + str(self.uuid) + ".tar.gz"
+            output_file_transfer_spec = os.path.join(self.working_directory, output_file_name) +" < " + output_file_name
+            #output_file_transfer_spec = os.path.join(self.working_directory, "output.tar.gz") +" < output.tar.gz"
+            logger.debug("Output transfer: " + output_file_transfer_spec)
             bj_file_transfers.append(output_file_transfer_spec)
             if filetransfers != None:
                 for t in filetransfers:
@@ -573,9 +577,10 @@ bigjob_agent = bigjob.bigjob_agent.bigjob_agent(args)
             if CLEANUP:
                 self.coordination.delete_pilot(self.pilot_url)                    
             #os.remove(os.path.join("/tmp", "bootstrap-"+str(self.uuid)))            
-        except:
+        except:            
             pass
             #traceback.print_stack()
+        logger.debug("Cancel Pilot Job finished")
 
     def wait(self):
         """ Waits for completion of all sub-jobs """        
